@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-#     Copyright 2021, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -27,7 +27,6 @@ import subprocess
 import sys
 from optparse import OptionParser
 
-from nuitka.freezer.Onefile import checkOnefileReadiness
 from nuitka.tools.Basics import goHome
 from nuitka.tools.testing.Common import (
     getInstalledPythonVersion,
@@ -509,8 +508,8 @@ def publishCoverageData():
         if sys.version_info > (3,):
             nuitka_id = nuitka_id.decode()
 
-        data_file.write("NUITKA_SOURCE_DIR=%r\n" % source_dir)
-        data_file.write("NUITKA_COMMIT=%r\n" % nuitka_id)
+        data_file.write("NUITKA_SOURCE_DIR='%s'\n" % source_dir)
+        data_file.write("NUITKA_COMMIT='%s'\n" % nuitka_id)
 
     copyToGlobalCoverageData("data.coverage", "meta.coverage." + suffix)
 
@@ -632,7 +631,11 @@ def main():
         return False
 
     def getExtraFlags(where, name, flags):
-        if options.assume_yes_for_downloads and name in ("onefile", "standalone"):
+        if options.assume_yes_for_downloads and name in (
+            "onefile",
+            "standalone",
+            "plugins",
+        ):
             yield "--assume-yes-for-downloads"
 
         if os.name == "nt" and options.mingw64:
@@ -756,9 +759,7 @@ def main():
                 executeSubTest("./tests/standalone/run_all.py search")
 
         if options.onefile_tests and not options.coverage:
-            if checkOnefileReadiness(
-                assume_yes_for_downloads=options.assume_yes_for_downloads
-            ):
+            if hasOnefileSupportedOS():
                 my_print(
                     "Running the onefile tests with options '%s' with '%s':"
                     % (flags, use_python)
